/*
 *  TrackRenderer — Render overlay tiles of GPS tracks for OpenLayers
 *  Copyright (C) 2008 Joerg Reuter <jreuter@yaina.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package de.yaina.trackrenderer;

/**
 * A collection of point / line styles and markers. Quick and dirty.
 * Should rather load XPM or PNG. Really.
 * 
 * @author Brownpaperbaghead
 */
public final class Pixmaps {

    public static final int P_LINE1 = 0;
    public static final int P_LINE3 = 1;
    public static final int P_LINE5 = 2;
    public static final int P_LINE7 = 3;
    public static final int P_LINE9 = 4;
    public static final int P_LINE11 = 5;
    public static final int P_MARKER1 = 6;
    public static final int P_MARKER2 = 7;
    private static int Line3_S = 3;
    private static byte[][] Line3 = {
        {1, 1, 1},
        {1, 1, 1},
        {1, 1, 1}
    };
    private static int Line5_S = 5;
    private static byte[][] Line5 = {
        {0, 1, 1, 1, 0},
        {1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1},
        {0, 1, 1, 1, 0}
    };
    private static int Line7_S = 7;
    private static byte[][] Line7 = {
        {0, 0, 1, 1, 1, 0, 0},
        {0, 1, 1, 1, 1, 1, 0},
        {1, 1, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 1, 1},
        {0, 1, 1, 1, 1, 1, 1},
        {0, 0, 1, 1, 1, 0, 0}
    };
    private static int Line9_S = 9;
    private static byte[][] Line9 = {
        {0, 0, 0, 1, 1, 1, 0, 0, 0},
        {0, 1, 1, 1, 1, 1, 1, 1, 0},
        {0, 1, 1, 1, 1, 1, 1, 1, 0},
        {1, 1, 1, 1, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 1, 1, 1, 1},
        {0, 1, 1, 1, 1, 1, 1, 1, 0},
        {0, 1, 1, 1, 1, 1, 1, 1, 0},
        {0, 0, 0, 1, 1, 1, 0, 0, 0}
    };
    private static int Line11_S = 11;
    private static byte[][] Line11 = {
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0},
        {0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0},
        {0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0},
        {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1},
        {0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0},
        {0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0},
        {0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0}
    };
    private static int Marker1_S = 11;
    private static byte[][] Marker1 = {
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1},
        {1, 1, 1, 1, 0, 0, 0, 1, 1, 1, 1},
        {1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0}
    };
    private static int Marker2_S = 11;
    private static byte[][] Marker2 = {
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0},
        {0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0},
        {0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0},
        {0, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0},
        {1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1},
        {1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1},
        {1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1},
        {0, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0},
        {0, 1, 1, 1, 0, 0, 0, 1, 1, 1, 0},
        {0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 0},
        {0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0}
    };

    /**
     * Return width of point/line style
     * 
     * @param pixmap index of style
     * @return width
     */
    public static int getSize(int pixmap) {
        switch (pixmap) {
            case P_LINE1:
                return 1;
            case P_LINE3:
                return Line3_S;
            case P_LINE5:
                return Line5_S;
            case P_LINE7:
                return Line7_S;
            case P_LINE9:
                return Line9_S;
            case P_LINE11:
                return Line11_S;
            case P_MARKER1:
                return Marker1_S;
            case P_MARKER2:
                return Marker2_S;
        }
        return 1;
    }

    /**
     * Return array of pixmap of point/line style
     * @param pixmap index of style
     * @return actual pixmap
     */
    public static byte[][] getPixmap(int pixmap) {
        switch (pixmap) {
            case P_LINE3:
                return Line3;
            case P_LINE5:
                return Line5;
            case P_LINE7:
                return Line7;
            case P_LINE9:
                return Line9;
            case P_LINE11:
                return Line11;
            case P_MARKER1:
                return Marker1;
            case P_MARKER2:
                return Marker2;
        }
        return null;
    }
}
