/*
 *  TrackRenderer — Render overlay tiles of GPS tracks for OpenLayers
 *  Copyright (C) 2008 Joerg Reuter <jreuter@yaina.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package de.yaina.trackrenderer;

/**
 * A canvas of a tiled image, takes care of coordinates exceeding the limits
 * of a tile and adjusts the values accordingly.
 * 
 * @author Joerg Reuter <jreuter@yaina.de>
 */
public class TileCanvas extends TileCollection {

    /**
     * 
     * @param tileDimX horizontal size of a tile
     * @param tileDimY vertical size of a tile
     */
    public TileCanvas(int tileDimX, int tileDimY) {
        super(tileDimX, tileDimY);
    }

    /* check whether the coordinates are outside the tile and adjust
     * the values
     */
    private TileCoordinates adjustTile(TileCoordinates point) {
        int dimx = getDimensionX();
        int dimy = getDimensionY();
        int x = point.x;
        int y = point.y;

        if (x < 0) {
            point.tile_x = point.tile_x + x / dimx - 1;
            point.x = dimx - -x % dimx;
        } else if (x >= dimx) {
            point.tile_x = point.tile_x + x / dimx;
            point.x = x % dimx;
        }

        if (y < 0) {
            point.tile_y = point.tile_y + y / dimy - 1;
            point.y = dimy - -y % dimy;
        } else if (point.y >= dimy) {
            point.tile_y = point.tile_y + y / dimy;
            point.y = y % dimy;
        }

        return point;
    }

    @Override
    public void setPoint(TileCoordinates point, byte colour) {
        super.setPoint(adjustTile(point), colour);
    }

    @Override
    public byte getPoint(TileCoordinates point) {
        return super.getPoint(adjustTile(point));
    }
}
